﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;

namespace RibbonTest
{
    /// <summary>
    /// Business-Layer: Aktivität
    /// </summary>
    public class Activity : INotifyPropertyChanged
    {
        private int activityId = 0;
        private string activityCode = String.Empty;
        private string activityName = String.Empty;

        public event PropertyChangedEventHandler PropertyChanged;

        public int ActivityId
        {
            get { return activityId; }
        }

        public string ActivityCode
        {
            get { return activityCode; }
            set 
            {
                if ( this.activityCode == value )
                    return;

                activityCode = value;
                NotifyPropertyChanged( "ActivityCode" );
            }
        }

        public string ActivityName
        {
            get { return activityName; }
            set {
                if ( this.activityName == value )
                    return;

                activityName = value;
                NotifyPropertyChanged( "ActivityName" );
            }
        }

        public Activity( int activityId, string activityCode, string activityName )
        {
            this.activityId = activityId;
            this.activityCode = activityCode;
            this.activityName = activityName;
        }

        public override bool Equals( object obj )
        {
            Activity a = obj as Activity;
            return a != null ? this.activityId.Equals( a.activityId ) : false;
        }

        public override int GetHashCode()
        {
            return this.activityId;
        }

        /// <summary>
        /// Implementierung des Notify-Patterns für die Datenbindung
        /// </summary>
        /// <param name="propertyName">Name der Eigenschaft die geändert wurde. Null für alle Eigenschaften</param>
        protected void NotifyPropertyChanged( string propertyName )
        {
            // Hier Persistent.Changed setzen
            // ...

            // Notify-Pattern
            OnPropertyChanged( this, new PropertyChangedEventArgs( propertyName ) );
        }

        /// <summary>
        /// Notify-Event auslösen
        /// </summary>
        protected virtual void OnPropertyChanged( Object sender, System.ComponentModel.PropertyChangedEventArgs e )
        {
            if ( PropertyChanged != null )
                PropertyChanged( sender, e );
        }

    }


}
