﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;

namespace RibbonTest
{
    public class ActivityGroup : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        private int groupId = 0;
        private string groupName = String.Empty;
        private ActivityContainer members = null;
        private OrganisationContainer organisations = null;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="groupId"></param>
        /// <param name="groupName"></param>
        /// <param name="members"></param>
        /// <param name="organisations"></param>
        public ActivityGroup( int groupId, string groupName, ActivityContainer members, OrganisationContainer organisations )
        {
            this.groupId = groupId;
            this.groupName = groupName;
            this.members = members;
            this.organisations = organisations;
        }

        public ActivityContainer Members
        {
            get { return members; }
        }

        public OrganisationContainer Organisations
        {
            get { return organisations; }
        }

        public string GroupName
        {
            get { return groupName; }
            set
            {
                if ( this.groupName == value )
                    return;

                groupName = value;
                NotifyPropertyChanged( "GroupName" );
            }
        }

        public int GroupId
        {
            get { return groupId; }
        }

        public override bool Equals( object obj )
        {
            ActivityGroup g = obj as ActivityGroup;
            return g != null ? this.groupId.Equals( g.groupId ) : false;
        }

        public override int GetHashCode()
        {
            return this.groupId;
        }

        /// <summary>
        /// Implementierung des Notify-Patterns für die Datenbindung
        /// </summary>
        /// <param name="propertyName">Name der Eigenschaft die geändert wurde. Null für alle Eigenschaften</param>
        private void NotifyPropertyChanged( string propertyName )
        {
            // Hier Persistent.Changed setzen
            // ...

            // Notify-Pattern
            OnPropertyChanged( this, new PropertyChangedEventArgs( propertyName ) );
        }

        /// <summary>
        /// Notify-Event auslösen
        /// </summary>
        protected virtual void OnPropertyChanged( Object sender, System.ComponentModel.PropertyChangedEventArgs e )
        {
            if ( PropertyChanged != null )
                PropertyChanged( sender, e );
        }

    }
}
