﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win.UltraWinTree;

namespace RibbonTest
{
    public partial class FormBindingListTest : Form
    {
        private ActivityViewModel activityView = null;
        private ActivityGroupViewModel groupView = null;
        private OrganisationViewModel orgView = null;

        public FormBindingListTest()
        {
            InitializeComponent();
        }

        private void Form_Load( object sender, EventArgs e )
        {
            // Test: Show Form within Tab-Page 
            FormKontoBuchungen f = new FormKontoBuchungen();
            f.Visible = true;
            f.TopLevel = false;
            f.FormBorderStyle = System.Windows.Forms.FormBorderStyle.None;
            f.Dock = DockStyle.Fill;
            this.ultraTabControl1.Tabs[1].TabPage.Controls.Add( f );

            // Test Bindings
            // -------------------------------------------
            // Organisation-Tree
            InitOrganisation();
            this.orgBindingSource.DataSource = this.orgView.BindingList;

            // Activity (1 level)
            ActivityContainer activities = this.InitActivities();
            // Connect BindingList to DataSource 
            this.activityBindingSource.DataSource = this.activityView.BindingList;

            // ActivityGroups (2 level)
            this.InitActivityGroup( activities );
            // Connect BindingList to DataSource 
            this.activityGroupBindingSource.DataSource = this.groupView.BindingList;
        }

        private ActivityContainer InitActivities()
        {
            ActivityContainer activities = new ActivityContainer();
            activities.Add( new Activity( 1, "A1", "Absence 1" ) );
            activities.Add( new Activity( 2, "A2", "Absence 2" ) );
            activities.Add( new Activity( 3, "A3", "Absence 3" ) );
            activities.Add( new Activity( 5, "S1", "Service 1" ) );
            activities.Add( new Activity( 6, "S2", "Service 2" ) );
            activities.Add( new Activity( 7, "S3", "Service 3" ) );

            this.activityView = new ActivityViewModel( activities );
            return activities;
        }

        private void InitActivityGroup( ActivityContainer activities )
        {
            OrganisationContainer orgContainer = new OrganisationContainer();
            orgContainer.Add( new OrgDepartment( null, 1, "Department 1" ) );
            orgContainer.Add( new OrgDepartment( null, 2, "Department 2" ) );

            ActivityGroupContainer groups = new ActivityGroupContainer();
            groups.Add( new ActivityGroup( 1, "Group 1", activities, orgContainer ) );
            groups.Add( new ActivityGroup( 2, "Group 2", activities, orgContainer ) );

            this.groupView = new ActivityGroupViewModel( groups );
        }

        private void InitOrganisation()
        {
            // Create Domain
            // -> Mandant
            OrgClient client = new OrgClient( 1, "Client 1" );

            // -> Department
            OrgDepartment dep1 = new OrgDepartment( client, 2, "Department 1" );
            OrgDepartment dep2 = new OrgDepartment( client, 3, "Department 2" );
            client.Childs.Add( dep1 );
            client.Childs.Add( dep2 );

            // -> Employees
            OrgEmployee e1 = new OrgEmployee( dep1, 4, "Employee 1" );
            OrgEmployee e2 = new OrgEmployee( dep1, 5, "Employee 2" );
            OrgEmployee e3 = new OrgEmployee( dep1, 6, "Employee 3" );
            dep1.Childs.Add( e1 );
            dep1.Childs.Add( e2 );
            dep1.Childs.Add( e3 );

            OrgEmployee e4 = new OrgEmployee( dep2, 7, "Employee 4" );
            OrgEmployee e5 = new OrgEmployee( dep2, 8, "Employee 5" );
            dep2.Childs.Add( e4 );
            dep2.Childs.Add( e5 );

            // Create View-Klassen
            //ClientView clientView = new ClientView( client );
            this.orgView = new OrganisationViewModel( client );
        }

        /// <summary>
        /// Event-Handler:
        /// </summary>
        private void BtnChange_Click( object sender, EventArgs e )
        {
            if ( this.EditCode.Text.Length == 0 || this.EditName.Text.Length == 0 )
                return;

            int index = Convert.ToInt32( this.EditCode.Text );

            // Domäne ändern
            this.activityView.Activities[index].ActivityName = this.EditName.Text;
        }

        private void TreeOrganisation_InitializeDataNode( object sender, Infragistics.Win.UltraWinTree.InitializeDataNodeEventArgs e )
        {
            OrgBase org = e.Node.ListObject as OrgBase;
            if ( org == null )
                return;

            e.Node.Key = org.OrgId.ToString();
        }

        private void TreeOrganisation_ColumnSetGenerated( object sender, Infragistics.Win.UltraWinTree.ColumnSetGeneratedEventArgs e )
        {
            // this handler is not called ???
            e.ColumnSet.NodeTextColumn = e.ColumnSet.Columns["OrgName"];
        }

        private void GridOrg_InitializeLayout( object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e )
        {
            for ( int i=0; i < e.Layout.Bands.Count; i++ )
            {
                for ( int col = 0; col < e.Layout.Bands[i].Columns.Count; col++ )
                {
                    e.Layout.Bands[i].Columns[col].Hidden = !e.Layout.Bands[i].Columns[col].Key.Equals( "OrgName" );
                }
            }
        }
    }
}
